[][src]Struct serde_path_to_error::Path

pub struct Path { /* fields omitted */ }

Path to the error value in the input, like dependencies.serde.typo1.

Use path.to_string() to get a string representation of the path with segments separated by periods, or use path.iter() to iterate over individual segments of the path.

Methods

impl Path[src]

Important traits for Segments<'a>
pub fn iter(&self) -> Segments[src]

Returns an iterator with element type &Segment.